@@ -2,6 +2,8 @@ import configparser
 import os
 import pathlib
 import logging
+import traceback
+from .uwException import * 
 
 class cmnConfig:
 
@@ -30,7 +32,7 @@ class cmnConfig:
         self.config_ini = None
         """ iniファイル読込内容 """
 
-    def getConfig(self, scriptPath):
+    def getConfig(self, scriptPath: str, configFileDirName: str = ''):
 
         """ 
         設定ファイルを読み込む 
@@ -41,15 +43,28 @@ class cmnConfig:
             共通設定クラス
         scriptPath : str
             スクリプトファイルパス
-
+        configFileDirName : str
+            config.iniがあるディレクトリ名
+        
         """
         
         # configparser宣言
         config_ini = configparser.ConfigParser()
 
-        # iniファイル読み込み
+        # iniファイルパス取得
         iniDirPath = pathlib.Path(os.path.abspath(os.path.dirname(scriptPath)))
-        iniFilePath = os.path.join(iniDirPath,'config.ini')
+        iniFilePath = os.path.join(iniDirPath, configFileDirName, 'config.ini')
+
+        # iniファイル存在確認
+        if (not os.path.exists(iniFilePath)): 
+            try:
+                raise iniFilePathError
+            except iniFilePathError as e:
+                print(e)
+                with open("log/error.log", 'a') as f:
+                    traceback.print_exc(file=f)
+
+        # iniファイル読込
         config_ini.read(iniFilePath, encoding='utf-8')
 
         # 各設定値をインスタンス変数にセット
