@@ -13,7 +13,7 @@ def getNow():
     # 日本時刻取得
     return datetime.datetime.now(datetime.timezone(datetime.timedelta(hours=9))) 
 
-def addDays(targetDate, addDays):
+def addDays(targetDate, addDays: int):
     
     """ 
     対象日付の日数を加算する
@@ -22,7 +22,7 @@ def addDays(targetDate, addDays):
     ----------
     targetDate :
         加算対象日付
-    addDays :
+    addDays : int
         加算する日数
     """
 
